@@ -2,7 +2,7 @@
 UBX configuration container dialog
 
 This is the pop-up dialog containing the various
-UBX configuration command widgets.
+UBX configuration command frames.
 
 NB: Individual UBX configuration commands do not have uniquely
 identifiable synchronous or asynchronous responses (e.g. unique
@@ -10,11 +10,7 @@ txn ID). The way we keep tabs on confirmation status is to
 maintain a list of all commands sent and the responses they're
 expecting. When we receive a response, we check against the list
 of awaited responses of the same type and flag the first one we
-find as 'confirmed'. This is generally reliable but not absolutely
-foolproof - if several commands awaiting the same response type are
-sent in quick succession, it's possible their responses may arrive
-out of order (or not at all) and we may flag the wrong command as
-'confirmed', or leave a confirmed command as 'pending'.
+find as 'confirmed'.
 
 Created on 19 Sep 2020
 
@@ -22,7 +18,7 @@ Created on 19 Sep 2020
 :copyright: SEMU Consulting © 2020
 :license: BSD 3-Clause
 """
-# pylint: disable=invalid-name
+# pylint: disable=invalid-name, too-many-instance-attributes
 
 from tkinter import (
     Toplevel,
@@ -36,6 +32,7 @@ from tkinter import (
     W,
 )
 from PIL import ImageTk, Image
+from pyubx2 import UBXMessage
 from pygpsclient.globals import (
     ICON_EXIT,
     UBX_MONVER,
@@ -58,6 +55,7 @@ from pygpsclient.ubx_preset_frame import UBX_PRESET_Frame
 from pygpsclient.ubx_cfgval_frame import UBX_CFGVAL_Frame
 from pygpsclient.ubx_solrate_frame import UBX_RATE_Frame
 from pygpsclient.ubx_dynamic_frame import UBX_Dynamic_Frame
+from pygpsclient.ubx_recorder_frame import UBX_Recorder_Frame
 
 
 class UBXConfigDialog(Toplevel):
@@ -84,22 +82,14 @@ class UBXConfigDialog(Toplevel):
         self.protocol("WM_DELETE_WINDOW", self.on_exit)
         self._img_exit = ImageTk.PhotoImage(Image.open(ICON_EXIT))
         self._cfg_msg_command = None
-        self._pending_confs = {
-            UBX_MONVER: (),
-            UBX_MONHW: (),
-            UBX_CFGPRT: (),
-            UBX_CFGMSG: (),
-            UBX_CFGVAL: (),
-            UBX_PRESET: (),
-            UBX_CFGRATE: (),
-        }
+        self._pending_confs = {}
         self._status = StringVar()
         self._status_cfgmsg = StringVar()
+        self._recordmode = False
 
         self._body()
         self._do_layout()
         self._reset()
-        # self._centre()
 
     def _body(self):
         """
@@ -123,6 +113,9 @@ class UBXConfigDialog(Toplevel):
         self._frm_device_info = UBX_INFO_Frame(
             self.__app, self, borderwidth=2, relief="groove"
         )
+        self._frm_recorder = UBX_Recorder_Frame(
+            self.__app, self, borderwidth=2, relief="groove"
+        )
         self._frm_config_port = UBX_PORT_Frame(
             self.__app, self, borderwidth=2, relief="groove"
         )
@@ -165,6 +158,7 @@ class UBXConfigDialog(Toplevel):
         # left column of grid
         for frm in (
             self._frm_device_info,
+            self._frm_recorder,
             self._frm_config_port,
             self._frm_config_rate,
             self._frm_config_msg,
@@ -239,63 +233,47 @@ class UBXConfigDialog(Toplevel):
         if self.__app.conn_status != CONNECTED:
             self.set_status("Device not connected", "red")
 
-    def _centre(self):
+    def set_pending(self, msgid: int, ubxfrm: int):
         """
-        Roughly center dialog in master window
-        NB: behaviour is slightly different across Windows, MacOS and Linux
-        """
-
-        dw = self.winfo_width()
-        dh = self.winfo_height()
-        mx = self.__master.winfo_x()
-        my = self.__master.winfo_y()
-        mw = self.__master.winfo_width()
-        mh = self.__master.winfo_height()
-        self.geometry(f"+{int(mx + (mw/2 - dw/2))}+{int(my + (mh/2 - dh/2))}")
-
-    def set_pending(self, key: int, val: list):
-        """
-        Set pending confirmation flag for configuration widget to
+        Set pending confirmation flag for UBX configuration frame to
         signify that it's waiting for a confirmation message.
 
-        :param int key: integer representing UBX configuration widget (0-6)
-        :param list val: list of confirmation messages that widget is awaiting
+        :param int msgid: UBX message identity
+        :param int ubxfrm: integer representing UBX configuration frame (0-6)
         """
 
-        self._pending_confs[key] = val
+        self._pending_confs[msgid] = ubxfrm
 
-    def update_pending(self, cfgtype, **kwargs):
+    def update_pending(self, msg: UBXMessage):
         """
         Receives polled confirmation message from the ubx_handler and
-        updates the widget that is waiting for this confirmation.
+        updates whichever UBX config frame is waiting for this confirmation.
 
-        :param str cfgtype: identity of UBX message containing config info
-        :param kwargs: status keywords and values from UBX config message
+        :param UBXMessage msg: UBX config message
         """
 
-        for (key, val) in self._pending_confs.items():
-            if cfgtype in val:
-                self.set_status(
-                    f"{cfgtype} GET message received",
-                    "red" if cfgtype == "ACK-NAK" else "green",
-                )
-                self._pending_confs[key] = ()  # reset awaiting conf flag
-                if key == UBX_MONVER:
-                    self._frm_device_info.update_status(cfgtype, **kwargs)
-                elif key == UBX_MONHW:
-                    self._frm_device_info.update_status(cfgtype, **kwargs)
-                elif key == UBX_CFGPRT:
-                    self._frm_config_port.update_status(cfgtype, **kwargs)
-                elif key == UBX_CFGRATE:
-                    self._frm_config_rate.update_status(cfgtype, **kwargs)
-                elif key == UBX_CFGMSG:
-                    self._frm_config_msg.update_status(cfgtype, **kwargs)
-                elif key == UBX_CFGVAL:
-                    self._frm_configdb.update_status(cfgtype, **kwargs)
-                elif key == UBX_PRESET:
-                    self._frm_preset.update_status(cfgtype, **kwargs)
-                elif key == UBX_CFGOTHER:
-                    self._frm_config_dynamic.update_status(cfgtype, **kwargs)
+        ubxfrm = self._pending_confs.get(msg.identity, None)
+
+        if ubxfrm is not None:
+            if ubxfrm in (UBX_MONVER, UBX_MONHW):
+                self._frm_device_info.update_status(msg)
+            elif ubxfrm == UBX_CFGPRT:
+                self._frm_config_port.update_status(msg)
+            elif ubxfrm == UBX_CFGRATE:
+                self._frm_config_rate.update_status(msg)
+            elif ubxfrm == UBX_CFGMSG:
+                self._frm_config_msg.update_status(msg)
+            elif ubxfrm == UBX_CFGVAL:
+                self._frm_configdb.update_status(msg)
+            elif ubxfrm == UBX_PRESET:
+                self._frm_preset.update_status(msg)
+            elif ubxfrm == UBX_CFGOTHER:
+                self._frm_config_dynamic.update_status(msg)
+
+            # reset all confirmation flags for this frame
+            for msgid in (msg.identity, "ACK-ACK", "ACK-NAK"):
+                if self._pending_confs.get(msgid, None) == ubxfrm:
+                    self._pending_confs.pop(msgid)
 
     def set_status(self, message: str, color: str = "blue"):
         """
@@ -339,3 +317,34 @@ class UBXConfigDialog(Toplevel):
         """
 
         return self._frm_container
+
+    @property
+    def recordmode(self) -> bool:
+        """
+        Getter for recording status.
+
+        :return: recording yes/no
+        :rtype: bool
+        """
+
+        return self._recordmode
+
+    @recordmode.setter
+    def recordmode(self, recordmode: bool):
+        """
+        Setter for record mode.
+
+        :param bool recordmode: recording yes/no
+        """
+
+        self._recordmode = recordmode
+
+    def send_command(self, msg: UBXMessage):
+        """
+        Send command to receiver and record to memory
+        if in 'record' mode.
+        """
+
+        self.__app.stream_handler.serial_write(msg.serialize())
+        if self.recordmode:
+            self._frm_recorder.update_record(msg)
